# Open Pectus
Pectus is a process control system for Unit Operations such as filtration, chromatography, precipitation, solubilization and refolding. Pectus implements a language called P-code which is used to write methods and control components on the Unit Operation.

Documentation is available at [Read the Docs](https://docs.openpectus.org/latest/).